@@ -1,7 +1,7 @@
 /*
-  $Id: iso1.c,v 1.3 2005/01/12 11:34:51 rocky Exp $
+  $Id: iso1.c,v 1.4 2005/02/03 07:32:32 rocky Exp $
 
-  Copyright (C) 2004 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,11 +54,19 @@ main(int argc, const char *argv[])
 {
   CdioList_t *entlist;
   CdioListNode_t *entnode;
+  char const *psz_fname;
+  iso9660_t *p_iso;
 
-  iso9660_t *p_iso = iso9660_open (ISO9660_IMAGE);
+  if (argc > 1) 
+    psz_fname = argv[1];
+  else 
+    psz_fname = ISO9660_IMAGE;
+
+  p_iso = iso9660_open (psz_fname);
   
   if (NULL == p_iso) {
-    fprintf(stderr, "Sorry, couldn't open ISO 9660 image %s\n", ISO9660_IMAGE);
+    fprintf(stderr, "Sorry, couldn't open %s as an ISO-9660 image\n", 
+	    psz_fname);
     return 1;
   }
 
@@ -66,16 +74,20 @@ main(int argc, const char *argv[])
     
   /* Iterate over the list of nodes that iso9660_ifs_readdir gives  */
   
-  _CDIO_LIST_FOREACH (entnode, entlist)
+  if (entlist) {
+    _CDIO_LIST_FOREACH (entnode, entlist)
     {
       char filename[4096];
       iso9660_stat_t *p_statbuf = 
 	(iso9660_stat_t *) _cdio_list_node_data (entnode);
       iso9660_name_translate(p_statbuf->filename, filename);
       printf ("/%s\n", filename);
+      free(p_statbuf);
     }
-
-  _cdio_list_free (entlist, true);
+    
+    _cdio_list_free (entlist, true);
+  }
+  
 
   iso9660_close(p_iso);
   return 0;
