@@ -1,5 +1,5 @@
 /*
-    $Id: bincue.c,v 1.10 2005/01/30 10:05:37 rocky Exp $
+    $Id: bincue.c,v 1.15 2005/02/17 07:03:37 rocky Exp $
 
     Copyright (C) 2002, 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
     Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
@@ -26,7 +26,7 @@
    (*.cue).
 */
 
-static const char _rcsid[] = "$Id: bincue.c,v 1.10 2005/01/30 10:05:37 rocky Exp $";
+static const char _rcsid[] = "$Id: bincue.c,v 1.15 2005/02/17 07:03:37 rocky Exp $";
 
 #include "image.h"
 #include "cdio_assert.h"
@@ -1128,7 +1128,7 @@ CdIo_t *
 cdio_open_cue (const char *psz_cue_name)
 {
   CdIo_t *ret;
-  _img_private_t *_data;
+  _img_private_t *p_data;
   char *psz_bin_name;
   
   cdio_funcs_t _funcs;
@@ -1146,6 +1146,7 @@ cdio_open_cue (const char *psz_cue_name)
   _funcs.get_drive_cap         = _get_drive_cap_image;
   _funcs.get_first_track_num   = _get_first_track_num_image;
   _funcs.get_hwinfo            = get_hwinfo_bincue;
+  _funcs.get_media_changed     = get_media_changed_image;
   _funcs.get_mcn               = _get_mcn_image;
   _funcs.get_num_tracks        = _get_num_tracks_image;
   _funcs.get_track_channels    = get_track_channels_image,
@@ -1158,22 +1159,24 @@ cdio_open_cue (const char *psz_cue_name)
   _funcs.lseek                 = _lseek_bincue;
   _funcs.read                  = _read_bincue;
   _funcs.read_audio_sectors    = _read_audio_sectors_bincue;
+  _funcs.read_data_sectors     = read_data_sectors_image;
   _funcs.read_mode1_sector     = _read_mode1_sector_bincue;
   _funcs.read_mode1_sectors    = _read_mode1_sectors_bincue;
   _funcs.read_mode2_sector     = _read_mode2_sector_bincue;
   _funcs.read_mode2_sectors    = _read_mode2_sectors_bincue;
+  _funcs.run_mmc_cmd           =  NULL;
   _funcs.set_arg               = _set_arg_image;
   
   if (NULL == psz_cue_name) return NULL;
   
-  _data                 = _cdio_malloc (sizeof (_img_private_t));
-  _data->gen.init       = false;
-  _data->psz_cue_name   = NULL;
+  p_data                 = calloc(1, sizeof (_img_private_t));
+  p_data->gen.init       = false;
+  p_data->psz_cue_name   = NULL;
   
-  ret = cdio_new ((void *)_data, &_funcs);
+  ret = cdio_new ((void *)p_data, &_funcs);
   
   if (ret == NULL) {
-    free(_data);
+    free(p_data);
     return NULL;
   }
   
@@ -1185,15 +1188,15 @@ cdio_open_cue (const char *psz_cue_name)
 		psz_cue_name);
   }
   
-  _set_arg_image (_data, "cue", psz_cue_name);
-  _set_arg_image (_data, "source", psz_bin_name);
-  _set_arg_image (_data, "access-mode", "bincue");
+  _set_arg_image (p_data, "cue", psz_cue_name);
+  _set_arg_image (p_data, "source", psz_bin_name);
+  _set_arg_image (p_data, "access-mode", "bincue");
   free(psz_bin_name);
   
-  if (_init_bincue(_data)) {
+  if (_init_bincue(p_data)) {
     return ret;
   } else {
-    _free_image(_data);
+    _free_image(p_data);
     free(ret);
     return NULL;
   }
