@@ -1,5 +1,5 @@
 /*
-    $Id: cd-info.c,v 1.139 2005/04/11 01:02:11 rocky Exp $
+    $Id: cd-info.c,v 1.142 2005/07/03 23:14:23 rocky Exp $
 
     Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
     Copyright (C) 1996, 1997, 1998  Gerd Knorr <kraxel@bytesex.org>
@@ -365,6 +365,21 @@ _log_handler (cdio_log_level_t level, const char message[])
   gl_default_cdio_log_handler (level, message);
 }
 
+#ifdef HAVE_CDDB
+static void 
+_cddb_log_handler (cddb_log_level_t level, const char message[])
+{
+  /* CDDB errors should not be considered fatal. */
+  if (level == CDDB_LOG_ERROR)
+    level = CDIO_LOG_WARN;
+
+  /* Might consider doing some sort of CDDB to cdio to log level conversion,
+     but right now it's a no op. */
+  
+  _log_handler(level, message);
+}
+#endif
+
 static void 
 print_cdtext_track_info(CdIo_t *p_cdio, track_t i_track, const char *psz_msg) {
    cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio, i_track);
@@ -707,10 +722,8 @@ init(void)
 {
   gl_default_cdio_log_handler = cdio_log_set_handler (_log_handler);
 #ifdef HAVE_CDDB
-  
-
   gl_default_cddb_log_handler = 
-    cddb_log_set_handler ((cddb_log_handler_t) _log_handler);
+    cddb_log_set_handler ((cddb_log_handler_t) _cddb_log_handler);
 #endif
 
 #ifdef HAVE_VCDINFO
@@ -857,7 +870,6 @@ main(int argc, const char *argv[])
       }
     }
     cdio_free_device_list(device_list);
-    if (device_list) free(device_list);
   }
 
   report(stdout, STRONG "\n");
