@@ -94,6 +94,7 @@
 #include <cdio/cdda.h>
 #include <cdio/paranoia.h>
 #include <cdio/bytesex.h>
+#include <cdio/mmc.h>
 #include "utils.h"
 #include "report.h"
 #include "version.h"
@@ -543,40 +544,41 @@ callback(long int inpos, paranoia_cb_mode_t function)
     memset(dispcache,' ',graph);
 }
 
-const char *optstring = "escCn:o:O:d:g:S:prRwafvqVQhZz::YXWBi:Tt:x:";
+const char *optstring = "aBcCd:efg:hi:m:n:o:O:pqQrRsS:Tt:VvwWx:XYZz::";
 
 struct option options [] = {
-	{"stderr-progress",           no_argument,       NULL, 'e'},
-	{"search-for-drive",          no_argument,       NULL, 's'},
-	{"force-cdrom-little-endian", no_argument,       NULL, 'c'},
+	{"abort-on-skip",             no_argument,       NULL, 'X'},
+	{"batch",                     no_argument,       NULL, 'B'},
+	{"disable-extra-paranoia",    no_argument,       NULL, 'Y'},
+	{"disable-fragmentation",     no_argument,       NULL, 'F'},
+	{"disable-paranoia",          no_argument,       NULL, 'Z'},
 	{"force-cdrom-big-endian",    no_argument,       NULL, 'C'},
-	{"force-default-sectors",     required_argument, NULL, 'n'},
-	{"force-search-overlap",      required_argument, NULL, 'o'},
 	{"force-cdrom-device",        required_argument, NULL, 'd'},
+	{"force-cdrom-little-endian", no_argument,       NULL, 'c'},
+	{"force-default-sectors",     required_argument, NULL, 'n'},
 	{"force-generic-device",      required_argument, NULL, 'g'},
 	{"force-read-speed",          required_argument, NULL, 'S'},
-	{"sample-offset",             required_argument, NULL, 'O'},
-	{"toc-offset",                required_argument, NULL, 't'},
-	{"toc-bias",                  no_argument,       NULL, 'T'},
-	{"output-raw",                no_argument,       NULL, 'p'},
-	{"output-raw-little-endian",  no_argument,       NULL, 'r'},
-	{"output-raw-big-endian",     no_argument,       NULL, 'R'},
-	{"output-wav",                no_argument,       NULL, 'w'},
-	{"output-aiff",               no_argument,       NULL, 'f'},
-	{"output-aifc",               no_argument,       NULL, 'a'},
-	{"batch",                     no_argument,       NULL, 'B'},
-	{"verbose",                   no_argument,       NULL, 'v'},
-	{"quiet",                     no_argument,       NULL, 'q'},
-	{"version",                   no_argument,       NULL, 'V'},
-	{"query",                     no_argument,       NULL, 'Q'},
+	{"force-search-overlap",      required_argument, NULL, 'o'},
 	{"help",                      no_argument,       NULL, 'h'},
-	{"disable-paranoia",          no_argument,       NULL, 'Z'},
-	{"disable-extra-paranoia",    no_argument,       NULL, 'Y'},
-	{"abort-on-skip",             no_argument,       NULL, 'X'},
-	{"test-mode",                 required_argument, NULL, 'x'},
-	{"disable-fragmentation",     no_argument,       NULL, 'F'},
-	{"output-info",               required_argument, NULL, 'i'},
+	{"mmc-timeout",               required_argument, NULL, 'm'},
 	{"never-skip",                optional_argument, NULL, 'z'},
+	{"output-aifc",               no_argument,       NULL, 'a'},
+	{"output-aiff",               no_argument,       NULL, 'f'},
+	{"output-info",               required_argument, NULL, 'i'},
+	{"output-raw",                no_argument,       NULL, 'p'},
+	{"output-raw-big-endian",     no_argument,       NULL, 'R'},
+	{"output-raw-little-endian",  no_argument,       NULL, 'r'},
+	{"output-wav",                no_argument,       NULL, 'w'},
+	{"query",                     no_argument,       NULL, 'Q'},
+	{"quiet",                     no_argument,       NULL, 'q'},
+	{"sample-offset",             required_argument, NULL, 'O'},
+	{"search-for-drive",          no_argument,       NULL, 's'},
+	{"stderr-progress",           no_argument,       NULL, 'e'},
+	{"test-mode",                 required_argument, NULL, 'x'},
+	{"toc-bias",                  no_argument,       NULL, 'T'},
+	{"toc-offset",                required_argument, NULL, 't'},
+	{"verbose",                   no_argument,       NULL, 'v'},
+	{"version",                   no_argument,       NULL, 'V'},
 
 	{NULL,0,NULL,0}
 };
@@ -588,9 +590,12 @@ static char *force_cdrom_device   = NULL;
 static char *info_file            = NULL;
 
 #define free_and_null(p) \
-  if (p) free(p);	 \
+  free(p);		 \
   p=NULL;		 
-  
+
+/* This is run automatically before leaving the program. 
+   Free allocated resources.
+*/  
 static void 
 cleanup (void) 
 {
@@ -601,22 +606,57 @@ cleanup (void)
   free_and_null(info_file);
 }
 
+/* Returns true if we have an integer argument. 
+   If so, pi_arg is set.
+   If no argument or integer argument found, we give an error
+   message and return false.
+*/
+static bool 
+get_int_arg(char c, long int *pi_arg) 
+{
+  long int i_arg;
+  char *p_end;
+  if (!optarg) {
+    /* This shouldn't happen, but we'll check anyway. */
+    fprintf(stderr,
+	    "An (integer) argument for option -%c was expected "
+	    " but not found. Option ignored\n", c);
+    return false;
+  }
+  i_arg = strtol(optarg, &p_end, 10);
+  if (errno == ERANGE) {
+    fprintf(stderr,
+	    "Value '%s' for option -%c out of range. Value %ld "
+	    "used instead.\n", optarg, c, i_arg);
+    *pi_arg = i_arg;
+    return false;
+  } else if (*p_end) {
+    fprintf(stderr,
+	    "Can't convert '%s' for option -%c completely into an integer. "
+	    "Option ignored.\n", optarg, c);
+    return false;
+  } else {
+    *pi_arg = i_arg;
+    return true;
+  }
+}
+
 int 
 main(int argc,char *argv[])
 {
   int   toc_bias             =  0;
-  int   toc_offset           =  0;
-  int   sample_offset        =  0;
   int   force_cdrom_endian   = -1;
-  int   force_cdrom_sectors  = -1;
-  int   force_cdrom_overlap  = -1;
-  int   force_cdrom_speed    = -1;
-  int   test_flags           =  0;
-  int   max_retries          = 20;
   int   output_type          =  1; /* 0=raw, 1=wav, 2=aifc */
   int   output_endian        =  0; /* -1=host, 0=little, 1=big */
   int   query_only           =  0;
   int   batch                =  0;
+  long int force_cdrom_overlap  = -1;
+  long int force_cdrom_sectors  = -1;
+  long int force_cdrom_speed    = -1;
+  long int sample_offset        =  0;
+  long int test_flags           =  0;
+  long int toc_offset           =  0;
+  long int max_retries          = 20;
 
   /* full paranoia, but allow skipping */
   int paranoia_mode=PARANOIA_MODE_FULL^PARANOIA_MODE_NEVERSKIP; 
@@ -630,6 +670,10 @@ main(int argc,char *argv[])
 
   while((c=getopt_long(argc,argv,optstring,options,&long_option_index))!=EOF){
     switch(c){
+    case 'a':
+      output_type=2;
+      output_endian=1;
+      break;
     case 'B':
       batch=1;
       break;
@@ -639,11 +683,17 @@ main(int argc,char *argv[])
     case 'C':
       force_cdrom_endian=1;
       break;
-    case 'n':
-      force_cdrom_sectors=atoi(optarg);
+    case 'e':
+      callscript=1;
+      fprintf(stderr,
+	      "Sending all callback output to stderr for wrapper script\n");
       break;
-    case 'o':
-      force_cdrom_overlap=atoi(optarg);
+    case 'f':
+      output_type=3;
+      output_endian=1;
+      break;
+    case 'F':
+      paranoia_mode&=~(PARANOIA_MODE_FRAGMENT);
       break;
     case 'g':
     case 'd':
@@ -655,8 +705,29 @@ main(int argc,char *argv[])
       }
       force_cdrom_device=strdup(optarg);
       break;
-    case 'S':
-      force_cdrom_speed=atoi(optarg);
+    case 'h':
+      usage(stdout);
+      exit(0);
+    case 'i':
+      if(info_file)free(info_file);
+      info_file=strdup(info_file);
+      break;
+    case 'm':
+      {
+	long int mmc_timeout_sec;
+	if (get_int_arg(c, &mmc_timeout_sec)) {
+	  mmc_timeout_ms = 1000*mmc_timeout_sec;
+	}
+      }
+      break;
+    case 'n':
+      get_int_arg(c, &force_cdrom_sectors);
+      break;
+    case 'o':
+      get_int_arg(c, &force_cdrom_overlap);
+      break;
+    case 'O':
+      get_int_arg(c, &sample_offset);
       break;
     case 'p':
       output_type=0;
@@ -666,90 +737,67 @@ main(int argc,char *argv[])
       output_type=0;
       output_endian=0;
       break;
-    case 'R':
-      output_type=0;
-      output_endian=1;
-      break;
-    case 'w':
-      output_type=1;
-      output_endian=0;
-      break;
-    case 'a':
-      output_type=2;
-      output_endian=1;
-      break;
-    case 'f':
-      output_type=3;
-      output_endian=1;
-      break;
-    case 'v':
-      verbose=CDDA_MESSAGE_PRINTIT;
-      quiet=0;
-      break;
-    case 's':
-      search=1;
-      break;
     case 'q':
       verbose=CDDA_MESSAGE_FORGETIT;
       quiet=1;
       break;
-    case 'e':
-      callscript=1;
-      fprintf(stderr,
-	      "Sending all callback output to stderr for wrapper script\n");
+    case 'Q':
+      query_only=1;
+      break;
+    case 'R':
+      output_type=0;
+      output_endian=1;
+      break;
+    case 's':
+      search=1;
+      break;
+    case 'S':
+      get_int_arg(c, &force_cdrom_speed);
+      break;
+    case 't':
+      get_int_arg(c, &toc_offset);
+      break;
+    case 'T':
+      toc_bias=-1;
+      break;
+    case 'v':
+      verbose=CDDA_MESSAGE_PRINTIT;
+      quiet=0;
       break;
     case 'V':
       fprintf(stderr,PARANOIA_VERSION);
       fprintf(stderr,"\n");
       exit(0);
       break;
-    case 'Q':
-      query_only=1;
+    case 'w':
+      output_type=1;
+      output_endian=0;
       break;
-    case 'h':
-      usage(stdout);
-      exit(0);
-    case 'Z':
-      paranoia_mode=PARANOIA_MODE_DISABLE; 
+    case 'W':
+      paranoia_mode&=~PARANOIA_MODE_REPAIR;
       break;
-    case 'z':
-      if (optarg) {
-        max_retries = atoi (optarg);
-        paranoia_mode&=~PARANOIA_MODE_NEVERSKIP;
-      } else {
-        paranoia_mode|=PARANOIA_MODE_NEVERSKIP;
-      }
+    case 'x':
+      get_int_arg(c, &test_flags);
+      break;
+    case 'X':
+      /*paranoia_mode&=~(PARANOIA_MODE_SCRATCH|PARANOIA_MODE_REPAIR);*/
+      abort_on_skip=1;
       break;
     case 'Y':
       paranoia_mode|=PARANOIA_MODE_OVERLAP; /* cdda2wav style overlap 
 						check only */
       paranoia_mode&=~PARANOIA_MODE_VERIFY;
       break;
-    case 'X':
-      /*paranoia_mode&=~(PARANOIA_MODE_SCRATCH|PARANOIA_MODE_REPAIR);*/
-      abort_on_skip=1;
+    case 'Z':
+      paranoia_mode=PARANOIA_MODE_DISABLE; 
       break;
-    case 'W':
-      paranoia_mode&=~PARANOIA_MODE_REPAIR;
-      break;
-    case 'F':
-      paranoia_mode&=~(PARANOIA_MODE_FRAGMENT);
-      break;
-    case 'i':
-      if(info_file)free(info_file);
-      info_file=strdup(info_file);
-      break;
-    case 'T':
-      toc_bias=-1;
-      break;
-    case 't':
-      toc_offset=atoi(optarg);
-      break;
-    case 'O':
-      sample_offset=atoi(optarg);
-      break;
-    case 'x':
-      test_flags=atoi(optarg);
+    case 'z':
+      if (optarg) {
+	get_int_arg(c, &max_retries);
+        paranoia_mode&=~PARANOIA_MODE_NEVERSKIP;
+      } else {
+        paranoia_mode|=PARANOIA_MODE_NEVERSKIP;
+      }
       break;
     default:
       usage(stderr);
@@ -825,8 +873,8 @@ main(int argc,char *argv[])
     }
     {
       char buffer[256];
-      sprintf(buffer,"Forcing default to read %d sectors; "
-	      "ignoring preset and autosense",force_cdrom_sectors);
+      sprintf(buffer,"Forcing default to read %ld sectors; "
+	      "ignoring preset and autosense", force_cdrom_sectors);
       report(buffer);
       d->nsectors=force_cdrom_sectors;
     }
@@ -840,8 +888,8 @@ main(int argc,char *argv[])
     }
     {
       char buffer[256];
-      sprintf(buffer,"Forcing search overlap to %d sectors; "
-	      "ignoring autosense",force_cdrom_overlap);
+      sprintf(buffer,"Forcing search overlap to %ld sectors; "
+	      "ignoring autosense", force_cdrom_overlap);
       report(buffer);
     }
   }
